Method: SchemaValidations::Config#except_type

Defined in:
lib/schema_validations.rb

#except_typeObject

:attr_accessor: except_type

List of validation types to exclude from automatic validation. Value is a single type, and array of types, or nil. Default is nil. A type is specified as, e.g., :validates_presence_of or simply :presence.



69
# File 'lib/schema_validations.rb', line 69

has_value :except_type, :default => nil